using System;
using System.ComponentModel;
using System.Xml.Serialization;

using Microsoft.Xna.Framework;

namespace EQIA.EQIDL
{
    public partial class Button : Control
    {
        private ButtonDrawTemplate myButtonDrawTemplate;
        private Point myDecalOffset;
        private Size myDecalSize;
        private string myRadioGroup, mySoundPressed, mySoundUp, mySoundFlyby;
        private bool myStyle_Checkbox;

        [XmlElement("ButtonDrawTemplate", IsNullable = false)]
        [Browsable(true), Description("Template that defines this button's art.")]
        public ButtonDrawTemplate ButtonDrawTemplate { get { return myButtonDrawTemplate; } set { myButtonDrawTemplate = value; } }

        [XmlElement("DecalOffset", IsNullable = false)]
        [Browsable(true), Description("Offset for this button's decal, if it exist.")]
        public Point DecalOffset { get { return myDecalOffset; } set { myDecalOffset = value; } }

        [XmlElement("DecalSize", IsNullable = false)]
        [Browsable(true), Description("Size to fit this button's decal in, if it exist.")]
        public Size DecalSize { get { return myDecalSize; } set { myDecalSize = value; } }

        [XmlElement("RadioGroup", IsNullable = false)]
        [Browsable(true), Description("This button is part of a radio group.")]
        public string RadioGroup { get { return myRadioGroup; } set { myRadioGroup = value; } }

        [XmlElement("Sound", IsNullable = false)]
        [Browsable(true), Description("Sound to play on button release (Not working in EQ).")]
        public string SoundUp { get { return mySoundUp; } set { mySoundUp = value; } }

        [XmlElement("SoundPressed", IsNullable = false)]
        [Browsable(true), Description("Sound to play on button press (Not working in EQ).")]
        public string SoundPressed { get { return mySoundPressed; } set { mySoundPressed = value; } }

        [XmlElement("SoundFlyby", IsNullable = false)]
        [Browsable(true), Description("Sound to play on button hover (Not working in EQ).")]
        public string SoundFlyby { get { return mySoundFlyby; } set { mySoundFlyby = value; } }

        [XmlElement("Style_Checkbox", IsNullable = false)]
        [Browsable(true), Description("This button acts as a checkbox (does not pop back up on mouse release).")]
        public bool Style_Checkbox { get { return myStyle_Checkbox; } set { myStyle_Checkbox = value; } }

        public Button() : this(null) { }
        public Button(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            Button button = obj as Button;
            if (button != null)
            {
                Style_Checkbox = button.Style_Checkbox;
                RadioGroup = button.RadioGroup;
                ButtonDrawTemplate = button.ButtonDrawTemplate;
                SoundPressed = button.SoundPressed;
                SoundUp = button.SoundUp;
                SoundFlyby = button.SoundFlyby;
                DecalOffset = button.DecalOffset;
                DecalSize = button.DecalSize;
            }
        }

    }
}
